==> gbsite-1.1.1.tar.gz: gbsite/include/download.php <==
<?
    /*
     * File: download.php
     *
     * Description:
     *     Contains the function used to handle uploaded files and
     * place those files in the correct place and update the database.
     *
     * Creator: Tim Dwelle
     * Created: ??/??/????
     *
     * Change Log:
     *     Tim Dwelle <?@?.?> ??/??/????
     *         - Initial Creation
     *     Chris Ryan <chris@greatbridge.com> 10/12/2000
     *         - Modified to use some of our global variables
     *           for the database
     *     Chris Ryan <chris@greatbridge.com> 10/23/2000
     *         - Added file and function comments
     *         - Added use of pg_freeresult() after completion of queries.
     *         - Reformatted some of the code
     */

    /*
     * Function: down_upload(...)
     *
     * Description:
     *     Takes in the information required and processes the info to
     * update the database and place the uploaded files into the correct
     * directory structure on the ftp site.
     */
    function down_upload($project_id, $project_name, $branch, $tarfile,
                         $tarfile_name, $tgzfile, $tgzfile_name, $zipfile,
                         $zipfile_name, $bz2file, $bz2file_name, $comments,
                         $member_id)
    {
        global $DOWNLOAD_FILE_PATH;
        global $conn;

        # determine path
        $path= $DOWNLOAD_FILE_PATH."/".$project_name;
        if (!file_exists($path)) {
            mkdir($path, 0775);
        }
        $path = $path."/".$branch;
        if (!file_exists($path)) {
            mkdir($path, 0775);
        }

        // copy files
        if ($tarfile != "none" && (substr($tarfile_name,-7,7) == ".tar.gz")) {
            copy($tarfile, $path."/".$tarfile_name) or die("Couldn't copy tarfile");
            $exists["tarfile"] = true;
        }
        if ($tgzfile != "none" && (substr($tgzfile_name,-4,4) == ".tgz")) {
            copy($tgzfile, $path."/".$tgzfile_name) or die("Couldn't copy tgz archive.");
            $exists["tgzfile"] = true;
        }
        if ($zipfile != "none" && (substr($zipfile_name,-4,4) == ".zip")) {
            copy($zipfile, $path."/".$zipfile_name) or die("Couldn't copy zipfile.");
            $exists["zipfile"] = true;
        }
        if ($bz2file != "none" && (substr($bz2file_name,-8,8) == ".tar.bz2")) {
            copy($bz2file, $path."/".$bz2file_name) or die("Couldn't copy bz2 archive.");
            $exists["bz2file"] = true;
        }


        // determine "filename" distinct from individual extensions
        if ($exists["tarfile"]) {
            $filename = substr($tarfile_name, 0, -7);
        }
        else if ($exists["tgzfile"]) {
            $filename = substr($tgzfile_name, 0, -4);
        }
        else if ($exists["bz2file"]) {
            $filename = substr($bz2file_name, 0, -8);
        }
        else if ($exists["zipfile"]) {
            $filename = substr($zipfile_name, 0, -4);
        } else {
            die("Fatal error. No file to add.");
        }

        $branch = sqlText($branch);
        $release = sqlText($filename);
        $comments = sqlText($comments);
        
        $query = "INSERT INTO download
                     (project_id,
                      branch,
                      release,
                      comments,
                      member_id)
                  VALUES
                     ($project_id,
                      $branch,
                      $release,
                      $comments,
                      $member_id)";
                      
        $result = pg_exec($conn, $query);

        # get a value to determine if we were successful or not
        $ret = (pg_cmdtuples($result) > 0);

        pg_freeresult($result);

        return $ret; # send back our success status
    }



    /*
     * Function: down_info_fetch($row, $project_name, $branch)
     *
     * Description:
     *     This function is called from down_info_list(). It gets
     * a list of files that are available to be downloaded.
     */
    function down_info_fetch($row, $project_name, $branch)
    {
        global $DOWNLOAD_FILE_PATH;
        global $DOWNLOAD_URL;
        global $conn; # it appears that this isn't needed here?!?

        $file = $row["release"];
        $date = $row["date_created"];
        $creator = array("id"=>$row["member_id"],
                         "name"=>$row["member_name"],
                         "email"=>$row["member_email"]);
        $branch = $row["branch"];
        $comments = $row["comments"];

        // get our paths to our files
        $path=$DOWNLOAD_FILE_PATH."/".$project_name."/".$branch;
        $zipfile = $path."/".$file.".zip";
        $tarfile = $path."/".$file.".tar.gz";
        $tgzfile = $path."/".$file.".tgz";
        $bz2file = $path."/".$file.".tar.bz2";

        $fileinfo["file"] = $file;
        $fileinfo["branch"] = $branch;
        $fileinfo["date"] = $date;
        $fileinfo["creator"] = $creator;
        $fileinfo["comments"] = $comments;

        if (file_exists($zipfile)) {
            $zip["name"] = $file.".zip";
            $zip["path"] = $zipfile;
            $zip["url"] = $DOWNLOAD_URL."/".$project_name."/".$branch."/".$file.".zip";
            $zip["size"] = filesize($zipfile);
            $fileinfo["zip"] = $zip;
        }
        if (file_exists($tarfile)) {
            $tar["name"] = $file.".tar.gz";
            $tar["path"] = $tarfile;
            $tar["url"] = $DOWNLOAD_URL."/".$project_name."/".$branch."/".$file.".tar.gz";
            $tar["size"] = filesize($tarfile);
            $fileinfo["tar"] = $tar;
        }
        if (file_exists($tgzfile)) {
            $tgz["name"] = $file.".tgz";
            $tgz["path"] = $tgzfile;
            $tgz["url"] = $DOWNLOAD_URL."/".$project_name."/".$branch."/".$file.".tgz";
            $tgz["size"] = filesize($tgzfile);
            $fileinfo["tgz"] = $tgz;
        }
        if (file_exists($bz2file)) {
            $bz2["name"] = $file.".tar.bz2";
            $bz2["path"] = $bz2file;
            $bz2["url"] = $DOWNLOAD_URL."/".$project_name."/".$branch."/".$file.".tar.bz2";
            $bz2["size"] = filesize($bz2file);
            $fileinfo["bz2"] = $bz2;
        }

        return $fileinfo;
    }


    /*
     * Function: down_info_list($project_id, $project_name, $branch)
     *
     * Description:
     *     Get a list of all the downloads available for this project.
     */
    function down_info_list($project_id, $project_name, $branch)
    {
        global $conn;

        $old_branch = $branch;
        $branch = sqlText($branch);
        
        $query = "SELECT    branch,
                            release,
                            comments,
                            member.member_id AS member_id,
                            member_name AS member_name,
                            email AS member_email,
                            download.date_created
                  FROM      download,
                            member
                  WHERE     download.project_id = $project_id
                  AND       download.branch = $branch
                  AND       download.member_id = member.member_id
                  ORDER BY  date_created DESC";

        $result = pg_exec($conn, $query);

        $rows = pg_numrows($result);
        for ($i=0; $i < $rows; $i++) {
            $rs = pg_fetch_array($result, $i);

            $data = down_info_fetch($rs, $project_name, $rs["branch"]);

            # quick fix for revisions of same file

            # new... just add it
            if (!$oldnames || !in_array($data["file"], $oldnames)) {
                $info[] = $data;
                $oldnames[] = $data["file"];
            } else {
                # old... remove file references
                unset($data["zip"]);
                unset($data["tar"]);
                unset($data["tgz"]);
                unset($data["bz2"]);
                $info[] = $data;
            }
        }

        pg_freeresult($result);

        return $info;                                    
    }

?>

==> gbsite-2.0.0.tar.gz: gbsite/include/download.php <==
<?
    /*
     * File: download.php
     *
     * Description:
     *     Contains the function used to handle uploaded files and
     * place those files in the correct place and update the database.
     *
     * Creator: Tim Dwelle
     * Created: ??/??/????
     *
     * Change Log:
     *     Tim Dwelle <?@?.?> ??/??/????
     *         - Initial Creation
     *     Chris Ryan <chris@greatbridge.com> 10/12/2000
     *         - Modified to use some of our global variables
     *           for the database
     *     Chris Ryan <chris@greatbridge.com> 10/23/2000
     *         - Added file and function comments
     *         - Added use of pg_freeresult() after completion of queries.
     *         - Reformatted some of the code
     *     Chris Ryan <chris@greatbridge.com> 01/18/2001
     *         - Added the file types of just .gz and .bz2
     */

    /*
     * Function: down_upload(...)
     *
     * Description:
     *     Takes in the information required and processes the info to
     * update the database and place the uploaded files into the correct
     * directory structure on the ftp site.
     */
    function down_upload($project_id, $project_name, $branch, $tarfile,
                         $tarfile_name, $tgzfile, $tgzfile_name, $zipfile,
                         $zipfile_name, $bz2file, $bz2file_name, $gzfile,
                         $gzfile_name, $bzfile, $bzfile_name, $zfile,
                         $zfile_name, $tzfile, $tzfile_name,
                         $comments, $member_id)
    {
        global $DOWNLOAD_FILE_PATH;
        global $conn;

        # determine path
        $path= $DOWNLOAD_FILE_PATH."/".$project_name;
        if (!file_exists($path)) {
            mkdir($path, 0775);
        }
        $path = $path."/".$branch;
        if (!file_exists($path)) {
            mkdir($path, 0775);
        }

        // copy files
        if ($gzfile != "none" && (substr($gzfile_name,-3) == ".gz")) {
            copy($gzfile, $path."/".$gzfile_name) or die("Couldn't copy gz file");
            $exists["gzfile"] = true;
        }
        if ($bzfile != "none" && (substr($bzfile_name,-4) == ".bz2")) {
            copy($bzfile, $path."/".$bzfile_name) or die ("Couldn't copy bz2 file");
            $exists["bzfile"] = true;
        }
        if ($tarfile != "none" && (substr($tarfile_name,-7,7) == ".tar.gz")) {
            copy($tarfile, $path."/".$tarfile_name) or die("Couldn't copy tarfile");
            $exists["tarfile"] = true;
        }
        if ($tgzfile != "none" && (substr($tgzfile_name,-4,4) == ".tgz")) {
            copy($tgzfile, $path."/".$tgzfile_name) or die("Couldn't copy tgz archive.");
            $exists["tgzfile"] = true;
        }
        if ($zipfile != "none" && (substr($zipfile_name,-4,4) == ".zip")) {
            copy($zipfile, $path."/".$zipfile_name) or die("Couldn't copy zipfile.");
            $exists["zipfile"] = true;
        }
        if ($bz2file != "none" && (substr($bz2file_name,-8,8) == ".tar.bz2")) {
            copy($bz2file, $path."/".$bz2file_name) or die("Couldn't copy bz2 archive.");
            $exists["bz2file"] = true;
        }
        if ($zfile != "none" && (substr($zfile_name,-2,2) == ".Z")) {
            copy($zfile, $path."/".$zfile_name) or die("Couldn't copy Z archive.");
            $exists["zfile"] = true;
        }
        if ($tzfile != "none" && (substr($tzfile_name,-6,6) == ".tar.Z")) {
            copy($tzfile, $path."/".$tzfile_name) or die("Couldn't copy .tar.Z archive.");
            $exists["tzfile"] = true;
        }


        // determine "filename" distinct from individual extensions
        if ($exists["tarfile"]) {
            $filename = substr($tarfile_name, 0, -7);
        } else if ($exists["tgzfile"]) {
            $filename = substr($tgzfile_name, 0, -4);
        } else if ($exists["bz2file"]) {
            $filename = substr($bz2file_name, 0, -8);
        } else if ($exists["zipfile"]) {
            $filename = substr($zipfile_name, 0, -4);
        } else if ($exists["gzfile"]) {
            $filename = substr($gzfile_name, 0, -3);
        } else if ($exists["bzfile"]) {
            $filename = substr($bzfile_name, 0, -4);
        } else if ($exists["zfile"]) {
            $filename = substr($zfile_name, 0, -2);
        } else if ($exists["tzfile"]) {
            $filename = substr($tzfile_name, 0, -6);
        } else {
            die("Fatal error. No file to add.");
        }

        $branch = sqlText($branch);
        $release = sqlText($filename);
        $comments = sqlText($comments);
        
        $query = "INSERT INTO download
                     (project_id,
                      branch,
                      release,
                      comments,
                      member_id)
                  VALUES
                     ($project_id,
                      $branch,
                      $release,
                      $comments,
                      $member_id)";
                      
        $result = pg_exec($conn, $query);

        # get a value to determine if we were successful or not
        $ret = (pg_cmdtuples($result) > 0);

        pg_freeresult($result);

        return $ret; # send back our success status
    }



    /*
     * Function: down_info_fetch($row, $project_name, $branch)
     *
     * Description:
     *     This function is called from down_info_list(). It gets
     * a list of files that are available to be downloaded.
     */
    function down_info_fetch($row, $project_name, $branch)
    {
        global $DOWNLOAD_FILE_PATH;
        global $DOWNLOAD_URL;
        global $conn; # it appears that this isn't needed here?!?

        $file = $row["release"];
        $date = $row["date_created"];
        $creator = array("id"=>$row["member_id"],
                         "name"=>$row["member_name"],
                         "email"=>$row["member_email"]);
        $branch = $row["branch"];
        $comments = $row["comments"];

        // get our paths to our files
        $path=$DOWNLOAD_FILE_PATH."/".$project_name."/".$branch;
        $zipfile = $path."/".$file.".zip";
        $tarfile = $path."/".$file.".tar.gz";
        $tgzfile = $path."/".$file.".tgz";
        $bz2file = $path."/".$file.".tar.bz2";
        $gzfile  = $path."/".$file.".gz";
        $bzfile  = $path."/".$file.".bz2";
        $zfile   = $path."/".$file.".Z";
        $tzfile  = $path."/".$file.".tar.Z";
        

        $fileinfo["file"] = $file;
        $fileinfo["branch"] = $branch;
        $fileinfo["date"] = $date;
        $fileinfo["creator"] = $creator;
        $fileinfo["comments"] = $comments;

        if (file_exists($zipfile)) {
            $zip["name"] = $file.".zip";
            $zip["path"] = $zipfile;
            $zip["url"] = $DOWNLOAD_URL."/".$project_name."/".$branch."/".$file.".zip";
            $zip["size"] = filesize($zipfile);
            $fileinfo["zip"] = $zip;
        }
        if (file_exists($tarfile)) {
            $tar["name"] = $file.".tar.gz";
            $tar["path"] = $tarfile;
            $tar["url"] = $DOWNLOAD_URL."/".$project_name."/".$branch."/".$file.".tar.gz";
            $tar["size"] = filesize($tarfile);
            $fileinfo["tar"] = $tar;
        }
        if (file_exists($tgzfile)) {
            $tgz["name"] = $file.".tgz";
            $tgz["path"] = $tgzfile;
            $tgz["url"] = $DOWNLOAD_URL."/".$project_name."/".$branch."/".$file.".tgz";
            $tgz["size"] = filesize($tgzfile);
            $fileinfo["tgz"] = $tgz;
        }
        if (file_exists($bz2file)) {
            $bz2["name"] = $file.".tar.bz2";
            $bz2["path"] = $bz2file;
            $bz2["url"] = $DOWNLOAD_URL."/".$project_name."/".$branch."/".$file.".tar.bz2";
            $bz2["size"] = filesize($bz2file);
            $fileinfo["bz2"] = $bz2;
        }
        if (file_exists($gzfile)) {
            $gz["name"] = $file.".gz";
            $gz["path"] = $gzfile;
            $gz["url"] = $DOWNLOAD_URL."/".$project_name."/".$branch."/".$file.".gz";
            $gz["size"] = filesize($gzfile);
            $fileinfo["gz"] = $gz;
        }
        if (file_exists($bzfile)) {
            $bz["name"] = $file.".bz2";
            $bz["path"] = $bzfile;
            $bz["url"] = $DOWNLOAD_URL."/".$project_name."/".$branch."/".$file.".bz2";
            $bz["size"] = filesize($bzfile);
            $fileinfo["bz"] = $bz;
        }
        if (file_exists($tzfile)) {
            $tz["name"] = $file.".tar.Z";
            $tz["path"] = $tzfile;
            $tz["url"] = $DOWNLOAD_URL."/".$project_name."/".$branch."/".$file.".tar.Z";
            $tz["size"] = filesize($tzfile);
            $fileinfo["tz"] = $tz;
        }
        if (file_exists($zfile)) {
            $z["name"] = $file.".Z";
            $z["path"] = $zfile;
            $z["url"] = $DOWNLOAD_URL."/".$project_name."/".$branch."/".$file.".Z";
            $z["size"] = filesize($zfile);
            $fileinfo["z"] = $z;
        }

        return $fileinfo;
    }


    /*
     * Function: down_info_list($project_id, $project_name, $branch)
     *
     * Description:
     *     Get a list of all the downloads available for this project.
     */
    function down_info_list($project_id, $project_name, $branch)
    {
        global $conn;

        $old_branch = $branch;
        $branch = sqlText($branch);
        
        $query = "SELECT    branch,
                            release,
                            comments,
                            member.member_id AS member_id,
                            member_name AS member_name,
                            email AS member_email,
                            download.date_created
                  FROM      download,
                            member
                  WHERE     download.project_id = $project_id
                  AND       download.branch = $branch
                  AND       download.member_id = member.member_id
                  ORDER BY  date_created DESC";

        $result = pg_exec($conn, $query);

        $rows = pg_numrows($result);
        for ($i=0; $i < $rows; $i++) {
            $rs = pg_fetch_array($result, $i);

            $data = down_info_fetch($rs, $project_name, $rs["branch"]);

            # quick fix for revisions of same file

            # new... just add it
            if (!$oldnames || !in_array($data["file"], $oldnames)) {
                $info[] = $data;
                $oldnames[] = $data["file"];
            } else {
                # old... remove file references
                unset($data["zip"]);
                unset($data["tar"]);
                unset($data["tgz"]);
                unset($data["bz2"]);
                unset($data["gz"]);
                unset($data["bz"]);
                unset($data["z"]);
                unset($data["tz"]);
                $info[] = $data;
            }
        }

        pg_freeresult($result);

        return $info;                                    
    }

?>
